pub struct EnumFromIntError(pub i32);Expand description
The error type returned when unable to convert an integer to an enum value.
Tuple Fields
0: i32Trait Implementations
Sourceimpl Clone for EnumFromIntError
impl Clone for EnumFromIntError
Sourcefn clone(&self) -> EnumFromIntError
fn clone(&self) -> EnumFromIntError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for EnumFromIntError
Sourceimpl Debug for EnumFromIntError
impl Debug for EnumFromIntError
Sourceimpl Display for EnumFromIntError
Available on try_from and crate feature std only.
impl Display for EnumFromIntError
Available on
try_from and crate feature std only.impl Eq for EnumFromIntError
Sourceimpl PartialEq for EnumFromIntError
impl PartialEq for EnumFromIntError
Sourcefn eq(&self, other: &EnumFromIntError) -> bool
fn eq(&self, other: &EnumFromIntError) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for EnumFromIntError